pub struct BayesianParametricResult {Show 16 fields
pub beta_mean: Vec<f64>,
pub beta_sd: Vec<f64>,
pub beta_lower: Vec<f64>,
pub beta_upper: Vec<f64>,
pub shape_mean: f64,
pub shape_sd: f64,
pub shape_lower: f64,
pub shape_upper: f64,
pub acceleration_factor_mean: Vec<f64>,
pub acceleration_factor_lower: Vec<f64>,
pub acceleration_factor_upper: Vec<f64>,
pub beta_samples: Vec<Vec<f64>>,
pub shape_samples: Vec<f64>,
pub log_posterior: Vec<f64>,
pub dic: f64,
pub waic: f64,
}Fields
beta_mean: Vec<f64>beta_sd: Vec<f64>beta_lower: Vec<f64>beta_upper: Vec<f64>shape_mean: f64shape_sd: f64shape_lower: f64shape_upper: f64acceleration_factor_mean: Vec<f64>acceleration_factor_lower: Vec<f64>acceleration_factor_upper: Vec<f64>beta_samples: Vec<Vec<f64>>shape_samples: Vec<f64>log_posterior: Vec<f64>dic: f64waic: f64Trait Implementations
Sourceimpl Clone for BayesianParametricResult
impl Clone for BayesianParametricResult
Sourcefn clone(&self) -> BayesianParametricResult
fn clone(&self) -> BayesianParametricResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BayesianParametricResult
impl Debug for BayesianParametricResult
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for BayesianParametricResultwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for BayesianParametricResultwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for BayesianParametricResult
impl<'py> IntoPyObject<'py> for BayesianParametricResult
Sourcetype Target = BayesianParametricResult
type Target = BayesianParametricResult
The Python output type
Sourcetype Output = Bound<'py, <BayesianParametricResult as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <BayesianParametricResult as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for BayesianParametricResult
impl PyClass for BayesianParametricResult
Sourceimpl PyClassImpl for BayesianParametricResult
impl PyClassImpl for BayesianParametricResult
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<BayesianParametricResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BayesianParametricResult>
type Layout = <<BayesianParametricResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<BayesianParametricResult>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyTypeInfo for BayesianParametricResult
impl PyTypeInfo for BayesianParametricResult
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for BayesianParametricResult