pub struct ConditionalSurvivalResult {
pub given_time: f64,
pub target_time: f64,
pub conditional_survival: f64,
pub ci_lower: f64,
pub ci_upper: f64,
pub n_at_risk: usize,
}Fields
given_time: f64target_time: f64conditional_survival: f64ci_lower: f64ci_upper: f64n_at_risk: usizeTrait Implementations
Sourceimpl Clone for ConditionalSurvivalResult
impl Clone for ConditionalSurvivalResult
Sourcefn clone(&self) -> ConditionalSurvivalResult
fn clone(&self) -> ConditionalSurvivalResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConditionalSurvivalResult
impl Debug for ConditionalSurvivalResult
Sourceimpl<'a, 'py> FromPyObject<'a, 'py> for ConditionalSurvivalResultwhere
Self: Clone,
impl<'a, 'py> FromPyObject<'a, 'py> for ConditionalSurvivalResultwhere
Self: Clone,
Sourceimpl<'py> IntoPyObject<'py> for ConditionalSurvivalResult
impl<'py> IntoPyObject<'py> for ConditionalSurvivalResult
Sourcetype Target = ConditionalSurvivalResult
type Target = ConditionalSurvivalResult
The Python output type
Sourcetype Output = Bound<'py, <ConditionalSurvivalResult as IntoPyObject<'py>>::Target>
type Output = Bound<'py, <ConditionalSurvivalResult as IntoPyObject<'py>>::Target>
The smart pointer type to use. Read more
Sourcefn into_pyobject(
self,
py: Python<'py>,
) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
fn into_pyobject( self, py: Python<'py>, ) -> Result<<Self as IntoPyObject<'_>>::Output, <Self as IntoPyObject<'_>>::Error>
Performs the conversion.
Sourceimpl PyClass for ConditionalSurvivalResult
impl PyClass for ConditionalSurvivalResult
Sourceimpl PyClassImpl for ConditionalSurvivalResult
impl PyClassImpl for ConditionalSurvivalResult
Sourceconst MODULE: Option<&str> = ::core::option::Option::None
const MODULE: Option<&str> = ::core::option::Option::None
Module which the class will be associated with. Read more
Sourceconst IS_BASETYPE: bool = false
const IS_BASETYPE: bool = false
#[pyclass(subclass)]
Sourceconst IS_SUBCLASS: bool = false
const IS_SUBCLASS: bool = false
#[pyclass(extends=…)]
Sourceconst IS_MAPPING: bool = false
const IS_MAPPING: bool = false
#[pyclass(mapping)]
Sourceconst IS_SEQUENCE: bool = false
const IS_SEQUENCE: bool = false
#[pyclass(sequence)]
Sourceconst IS_IMMUTABLE_TYPE: bool = false
const IS_IMMUTABLE_TYPE: bool = false
#[pyclass(immutable_type)]
Sourceconst RAW_DOC: &'static CStr = c"\x00"
const RAW_DOC: &'static CStr = c"\x00"
Docstring for the class provided on the struct or enum. Read more
Sourceconst DOC: &'static CStr
const DOC: &'static CStr
Fully rendered class doc, including the
text_signature if a constructor is defined. Read moreSourcetype Layout = <<ConditionalSurvivalResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<ConditionalSurvivalResult>
type Layout = <<ConditionalSurvivalResult as PyClassImpl>::BaseNativeType as PyClassBaseType>::Layout<ConditionalSurvivalResult>
Description of how this class is laid out in memory
Sourcetype ThreadChecker = NoopThreadChecker
type ThreadChecker = NoopThreadChecker
This handles following two situations: Read more
Sourcetype PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
type PyClassMutability = <<PyAny as PyClassBaseType>::PyClassMutability as PyClassMutability>::MutableChild
Immutable or mutable
Sourcetype BaseNativeType = PyAny
type BaseNativeType = PyAny
The closest native ancestor. This is
PyAny by default, and when you declare
#[pyclass(extends=PyDict)], it’s PyDict.fn items_iter() -> PyClassItemsIter
fn lazy_type_object() -> &'static LazyTypeObject<Self>
Sourcefn dict_offset() -> Option<PyObjectOffset>
fn dict_offset() -> Option<PyObjectOffset>
Used to provide the dictoffset slot
(equivalent to tp_dictoffset)
Sourcefn weaklist_offset() -> Option<PyObjectOffset>
fn weaklist_offset() -> Option<PyObjectOffset>
Used to provide the weaklistoffset slot
(equivalent to tp_weaklistoffset
Sourceimpl PyClassNewTextSignature for ConditionalSurvivalResult
impl PyClassNewTextSignature for ConditionalSurvivalResult
const TEXT_SIGNATURE: &'static str = "(given_time, target_time, conditional_survival, ci_lower, ci_upper, n_at_risk)"
Sourceimpl PyMethods<ConditionalSurvivalResult> for PyClassImplCollector<ConditionalSurvivalResult>
impl PyMethods<ConditionalSurvivalResult> for PyClassImplCollector<ConditionalSurvivalResult>
fn py_methods(self) -> &'static PyClassItems
Sourceimpl PyTypeInfo for ConditionalSurvivalResult
impl PyTypeInfo for ConditionalSurvivalResult
Sourceconst NAME: &str = <Self as ::pyo3::PyClass>::NAME
const NAME: &str = <Self as ::pyo3::PyClass>::NAME
👎Deprecated since 0.28.0:
prefer using ::type_object(py).name() to get the correct runtime value
Class name.
Sourceconst MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
const MODULE: Option<&str> = <Self as ::pyo3::impl_::pyclass::PyClassImpl>::MODULE
👎Deprecated since 0.28.0:
prefer using ::type_object(py).module() to get the correct runtime value
Module name, if any.
Sourcefn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
fn type_object_raw(py: Python<'_>) -> *mut PyTypeObject
Returns the PyTypeObject instance for this type.
Sourcefn type_object(py: Python<'_>) -> Bound<'_, PyType>
fn type_object(py: Python<'_>) -> Bound<'_, PyType>
Returns the safe abstraction over the type object.
impl DerefToPyAny for ConditionalSurvivalResult